
# Slot: class_uri


URI of the class in an RDF environment

URI: [linkml:class_uri](https://w3id.org/linkml/class_uri)


## Domain and Range

[ClassDefinition](ClassDefinition.md) &#8594;  <sub>0..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
